
From: Darren Hart <dvhltc@us.ibm.com>

try_to_free_pages accepts a third argument, order, but hasn't used it since
before 2.6.0.  The following patch removes the argument and updates all the
calls to try_to_free_pages.

Signed-off-by: Darren Hart <dvhltc@us.ibm.com>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 fs/buffer.c          |    2 +-
 include/linux/swap.h |    2 +-
 mm/page_alloc.c      |    2 +-
 mm/vmscan.c          |    3 +--
 4 files changed, 4 insertions(+), 5 deletions(-)

diff -puN fs/buffer.c~vm-try_to_free_pages-unused-argument fs/buffer.c
--- 25/fs/buffer.c~vm-try_to_free_pages-unused-argument	Mon May 23 15:43:49 2005
+++ 25-akpm/fs/buffer.c	Mon May 23 15:43:49 2005
@@ -528,7 +528,7 @@ static void free_more_memory(void)
 	for_each_pgdat(pgdat) {
 		zones = pgdat->node_zonelists[GFP_NOFS&GFP_ZONEMASK].zones;
 		if (*zones)
-			try_to_free_pages(zones, GFP_NOFS, 0);
+			try_to_free_pages(zones, GFP_NOFS);
 	}
 }
 
diff -puN include/linux/swap.h~vm-try_to_free_pages-unused-argument include/linux/swap.h
--- 25/include/linux/swap.h~vm-try_to_free_pages-unused-argument	Mon May 23 15:43:49 2005
+++ 25-akpm/include/linux/swap.h	Mon May 23 15:43:49 2005
@@ -186,7 +186,7 @@ extern int rotate_reclaimable_page(struc
 extern void swap_setup(void);
 
 /* linux/mm/vmscan.c */
-extern int try_to_free_pages(struct zone **, unsigned int, unsigned int);
+extern int try_to_free_pages(struct zone **, unsigned int);
 extern int shrink_all_memory(int);
 extern unsigned int reclaim_clean_pages(struct zone *, long, int);
 extern int vm_swappiness;
diff -puN mm/page_alloc.c~vm-try_to_free_pages-unused-argument mm/page_alloc.c
--- 25/mm/page_alloc.c~vm-try_to_free_pages-unused-argument	Mon May 23 15:43:49 2005
+++ 25-akpm/mm/page_alloc.c	Mon May 23 15:43:49 2005
@@ -834,7 +834,7 @@ rebalance:
 	reclaim_state.reclaimed_slab = 0;
 	p->reclaim_state = &reclaim_state;
 
-	did_some_progress = try_to_free_pages(zones, gfp_mask, order);
+	did_some_progress = try_to_free_pages(zones, gfp_mask);
 
 	p->reclaim_state = NULL;
 	p->flags &= ~PF_MEMALLOC;
diff -puN mm/vmscan.c~vm-try_to_free_pages-unused-argument mm/vmscan.c
--- 25/mm/vmscan.c~vm-try_to_free_pages-unused-argument	Mon May 23 15:43:49 2005
+++ 25-akpm/mm/vmscan.c	Mon May 23 15:43:49 2005
@@ -958,8 +958,7 @@ shrink_caches(struct zone **zones, struc
  * holds filesystem locks which prevent writeout this might not work, and the
  * allocation attempt will fail.
  */
-int try_to_free_pages(struct zone **zones,
-		unsigned int gfp_mask, unsigned int order)
+int try_to_free_pages(struct zone **zones, unsigned int gfp_mask)
 {
 	int priority;
 	int ret = 0;
_
